@@ -26,7 +26,7 @@ from .xbar import fix_environment
 # Canonical name of the CLI.
 CLI_NAME = "mpm"
 
-__version__ = "4.1.0"
+__version__ = "4.3.0"
 """ Examples of valid version strings according :pep:`440#version-scheme`:
 
 .. code-block:: python
@@ -48,4 +48,11 @@ env_data = get_profile(scrub=True)
 logger = logging.getLogger(__name__)
 
 
+def reset_logger():
+    """Forces the logger level to reset at the end of each CLI execution, as it
+    might pollute the logger state between multiple test calls.
+    """
+    logger.setLevel(logging.NOTSET)
+
+
 fix_environment()
