@@ -32,7 +32,7 @@ from .version import parse_version
 from .xbar import run
 
 # Rendering format of CLI in JSON fields.
-CLI_FORMATS = frozenset(["plain", "fragments", "bitbar", "xbar"])
+CLI_FORMATS = frozenset(["plain", "fragments", "xbar"])
 
 
 class CLIError(Exception):
@@ -146,7 +146,7 @@ class PackageManager:
         Only checks if the file exists. Its executability will be assessed later. See
         the ``self.executable`` method below.
 
-        Returns `None` if no CLI was found or those found were not a file.
+        Returns ``None`` if no CLI was found or those found were not a file.
         """
         # Check if the path exist in any of the environment locations.
         env_path = ":".join(self.cli_search_path + [os.getenv("PATH")])
@@ -178,7 +178,7 @@ class PackageManager:
         """Invoke the manager and extract its own reported version.
 
         It does matter if this method return unsanitized and crappy string. The
-        `version()` method below will clean and normalized it.
+        ``version()`` method below will clean and normalized it.
         """
         raise NotImplementedError
 
@@ -226,10 +226,11 @@ class PackageManager:
         """Is the package manager available and ready-to-use on the system?
 
         Returns True only if the main CLI:
-            1 - is supported on the current platform,
-            2 - was found on the system,
-            3 - is executable, and
-            4 - match the version requirement.
+
+        # is supported on the current platform,
+        # was found on the system,
+        # is executable, and
+        # match the version requirement.
         """
         return bool(self.supported and self.cli_path and self.executable and self.fresh)
 
@@ -280,8 +281,8 @@ class PackageManager:
         return output
 
     def run_cli(self, *args, dry_run=False):
-        """Like the `run` method above, but execute the binary pointed to by
-        the `cli_path` property set in the current instance.
+        """Like the ``run`` method above, but execute the binary pointed to by
+        the ``cli_path`` property set in the current instance.
         """
         return self.run(self.cli_path, args, dry_run=dry_run)
 
@@ -319,6 +320,13 @@ class PackageManager:
             logger.warning(f"Search not implemented for {self.id}.")
             return {}
 
+    def install(self, package_id):
+        """Install one package and one only."""
+        if self.install.__func__.__qualname__ == PackageManager.install.__qualname__:
+            logger.warning(f"Install not implemented for {self.id}.")
+            return
+        logger.info(f"Install {package_id} package from {self.id}...")
+
     @property
     def outdated(self):
         """List currently installed packages having a new version available.
@@ -335,7 +343,12 @@ class PackageManager:
 
     def upgrade(self, package_id=None, dry_run=False):
         """Perform the upgrade of the provided package to latest version."""
-        return self.run(self.upgrade_cli(package_id), dry_run=dry_run)
+        try:
+            upgrade_cli = self.upgrade_cli(package_id)
+        except NotImplementedError:
+            logger.warning(f"Upgrade not implemented for {self.id}.")
+            return
+        return self.run(upgrade_cli, dry_run=dry_run)
 
     def upgrade_all_cli(self):
         """Return a shell-compatible full-CLI to upgrade all packages."""
@@ -368,13 +381,7 @@ class PackageManager:
 
         * ``plain`` returns a simple string
         * ``fragments`` returns a list of strings
-        * ``xbar`` (or ``bitbar``) returns a CLI with parameters formatted into
-        the xbar dialect
-
-        ..warning:
-
-            ``bitbar`` is deprecated but is provided as temporary alias to
-            ``xbar`` to provide a smooth transition to the rebooted project.
+        * ``xbar`` returns a CLI with parameters formatted into the xbar dialect
         """
         assert isinstance(cmd, list)
         assert cli_format in CLI_FORMATS
@@ -387,12 +394,8 @@ class PackageManager:
             return " ".join(cmd)
 
         # Renders the CLI into xbar dialect.
-        xbar_cli = ""
-        for index, param in enumerate(cmd):
-            if index == 0:
-                xbar_cli += f"shell={param}"
-            else:
-                if "=" in param:
-                    param = f'\\"{param}\\"'
-                xbar_cli += f" param{index}={param}"
-        return xbar_cli
+        xbar_params = []
+        for index, param_value in enumerate(cmd):
+            param_id = "shell" if index == 0 else f"param{index}"
+            xbar_params.append(f"{param_id}={param_value}")
+        return " | ".join(xbar_params)
