@@ -23,20 +23,21 @@ from functools import partial
 from io import TextIOWrapper
 from operator import getitem, itemgetter
 from pathlib import Path
-from sys import __stdin__, __stdout__
 from time import time as time_now
 
 import click
 import click_log
-import tomlkit
+import tomli
+import tomli_w
 from boltons.cacheutils import LRI, cached
 from boltons.strutils import complement_int_list, int_ranges_from_int_list, strip_ansi
 from cli_helpers.tabular_output import TabularOutputFormatter
 from click_help_colors import HelpColorsCommand, HelpColorsGroup, version_option
 from simplejson import dumps as json_dumps
 
-from . import CLI_NAME, __version__, env_data, logger
+from . import CLI_NAME, __version__, env_data, logger, reset_logger
 from .base import CLI_FORMATS, CLIError, PackageManager
+from .config import load_conf
 from .managers import pool
 from .platform import CURRENT_OS_ID, WINDOWS, os_label
 from .version import TokenizedString
@@ -190,12 +191,11 @@ class timeit:
             click.echo(f"Execution time: {elapsed:.3} seconds.")
 
 
-@click.group()
-@click_log.simple_verbosity_option(
-    logger,
-    default="INFO",
-    metavar="LEVEL",
-    help="Either CRITICAL, ERROR, WARNING, INFO or DEBUG. Defaults to INFO.",
+@click.group(
+    context_settings=dict(
+        show_default=True,
+        auto_envvar_prefix=CLI_NAME,
+    )
 )
 @click.option(
     "-m",
@@ -203,52 +203,68 @@ class timeit:
     type=click.Choice(pool(), case_sensitive=False),
     multiple=True,
     help="Restrict sub-command to a subset of package managers. Repeat to "
-    "select multiple managers. Defaults to all.",
+    "select multiple managers.",
 )
 @click.option(
     "-e",
     "--exclude",
     type=click.Choice(pool(), case_sensitive=False),
     multiple=True,
-    help="Exclude a package manager. Repeat to exclude multiple managers. "
-    "Defaults to none.",
+    help="Exclude a package manager. Repeat to exclude multiple managers.",
 )
 @click.option(
     "--ignore-auto-updates/--include-auto-updates",
     default=True,
     help="Report all outdated packages, including those tagged as "
-    "auto-updating. Defaults to include all packages. Only applies to "
-    "'outdated' and 'upgrade' commands.",
+    "auto-updating. Only applies to 'outdated' and 'upgrade' commands.",
 )
 @click.option(
     "-o",
     "--output-format",
     type=click.Choice(sorted(RENDERING_MODES), case_sensitive=False),
-    default="fancy_grid",
-    help="Rendering mode of the output. Defaults to fancy-grid.",
+    default="psql_unicode",
+    help="Rendering mode of the output.",
 )
 @click.option(
     "-s",
     "--sort-by",
     type=click.Choice(SORTABLE_FIELDS, case_sensitive=False),
     default="manager_id",
-    help="Sort results. Defaults to manager_id.",
+    help="Sort results.",
 )
 @click.option(
     "--stats/--no-stats",
     default=True,
-    help="Print per-manager package statistics. Active by default.",
+    help="Print per-manager package statistics.",
 )
 @click.option(
     "--time/--no-time",
     default=False,
-    help="Measure and print elapsed execution time. Inactive by default.",
+    help="Measure and print elapsed execution time.",
 )
 @click.option(
     "--stop-on-error/--continue-on-error",
     default=False,
-    help="Stop right away or continue operations on manager CLI error. Defaults to "
-    "continue.",
+    help="Stop right away or continue operations on manager CLI error.",
+)
+@click.option(
+    "-C",
+    "--config",
+    metavar="CONFIG_PATH",
+    type=click.Path(path_type=Path, resolve_path=True),
+    # default=default_conf_path(),
+    help="Location of the configuration file.",
+    # Force eagerness so the config option's callback gets the oportunity to set the
+    # default_map values before the other options use them.
+    is_eager=True,
+    callback=load_conf,
+    expose_value=False,
+)
+@click_log.simple_verbosity_option(
+    logger,
+    default="INFO",
+    metavar="LEVEL",
+    help="Either CRITICAL, ERROR, WARNING, INFO or DEBUG.",
 )
 @version_option(
     version=__version__,
@@ -258,6 +274,7 @@ class timeit:
     message=f"%(prog)s %(version)s\n{env_data}",
     message_color="bright_black",
 )
+@click.help_option("-h", "--help")
 @click.pass_context
 def cli(
     ctx,
@@ -271,16 +288,15 @@ def cli(
     stop_on_error,
 ):
     """CLI for multi-package manager upgrades."""
-    # TODO: merge CLI parameters and config file here.
-    # See: https://github.com/kdeldycke/meta-package-manager/issues/66
 
+    # Print log level.
     level = logger.level
     level_name = logging._levelToName.get(level, level)
     logger.debug(f"Verbosity set to {level_name}.")
 
     # Target all available managers by default.
     target_ids = set(pool())
-    # Only keeps the subset of selected by the user.
+    # Only keeps the subset selected by the user.
     if manager:
         target_ids = target_ids.intersection(manager)
     # Remove managers excluded by the user.
@@ -327,6 +343,8 @@ def cli(
         "time": time,
     }
 
+    ctx.call_on_close(reset_logger)
+
 
 @cli.command(short_help="List supported package managers and their location.")
 @click.pass_context
@@ -500,14 +518,12 @@ def installed(ctx):
     "--extended/--package-name",
     default=False,
     help="Extend search to additional package metadata like description, "
-    "instead of restricting it package ID and name. Defaults to package ID "
-    "search.",
+    "instead of restricting it package ID and name.",
 )
 @click.option(
     "--exact/--fuzzy",
     default=False,
-    help="Only returns exact matches, or enable fuzzy search in substrings. "
-    "Fuzzy by default.",
+    help="Only returns exact matches, or enable fuzzy search in substrings.",
 )
 @click.argument("query", type=click.STRING, required=True)
 @click.pass_context
@@ -606,13 +622,36 @@ def search(ctx, extended, exact, query):
         print_stats(matches)
 
 
+@cli.command(short_help="Install a package.")
+@click.argument("package_id", type=click.STRING, required=True)
+@click.pass_context
+@timeit()
+def install(ctx, package_id):
+    """Install a package from one package manager and one only.
+
+    The -m\--manager option is required."""
+    active_managers = ctx.obj["active_managers"]
+    active_managers = list(active_managers)
+
+    if not active_managers:
+        logger.fatal(f"A package manager must be provided via the -m/--manager option.")
+        ctx.exit(2)
+    if len(active_managers) > 1:
+        logger.fatal(f"Only one package manager should be provided.")
+        ctx.exit(2)
+
+    manager = active_managers.pop()
+    output = manager.install(package_id)
+    click.echo(output)
+
+
 @cli.command(short_help="List outdated packages.")
 @click.option(
     "-c",
     "--cli-format",
     type=click.Choice(CLI_FORMATS, case_sensitive=False),
     default="plain",
-    help="Format of CLI fields in JSON output. Defaults to plain.",
+    help="Format of CLI fields in JSON output.",
 )
 @click.pass_context
 @timeit()
@@ -736,12 +775,7 @@ def backup(ctx, toml_output):
     active_managers = ctx.obj["active_managers"]
     stats = ctx.obj["stats"]
 
-    # XXX Hack for unittests to pass, while we wait for
-    # https://github.com/pallets/click/pull/1497
-    if isinstance(toml_output, TextIOWrapper):
-        toml_output = __stdout__
-
-    is_stdout = toml_output is __stdout__
+    is_stdout = isinstance(toml_output, TextIOWrapper)
     toml_filepath = toml_output.name if is_stdout else Path(toml_output.name).resolve()
     logger.info(f"Backup package list to {toml_filepath}")
 
@@ -753,11 +787,9 @@ def backup(ctx, toml_output):
             logger.error("Target file is not a TOML file.")
             return
 
-    # Initialize the TOML structure.
-    doc = tomlkit.document()
     # Leave some metadata as comment.
-    doc.add(tomlkit.comment(f"Generated by {CLI_NAME} {__version__}."))
-    doc.add(tomlkit.comment("Timestamp: {}.".format(datetime.now().isoformat())))
+    doc = f"# Generated by {CLI_NAME} {__version__}.\n"
+    doc += "# Timestamp: {}.\n".format(datetime.now().isoformat())
 
     installed_data = {}
 
@@ -771,17 +803,19 @@ def backup(ctx, toml_output):
             "packages": manager.installed.values(),
         }
 
-        manager_section = tomlkit.table()
-        pkg_data = sorted(
-            [(p["id"], p["installed_version"]) for p in manager.installed.values()]
+        pkg_data = dict(
+            sorted(
+                [
+                    (p["id"], str(p["installed_version"]))
+                    for p in manager.installed.values()
+                ]
+            )
         )
-        for package_id, package_version in pkg_data:
-            # Version specifier is inspired by Poetry.
-            manager_section.add(package_id, f"^{package_version}")
-        if pkg_data:
-            doc.add(manager.id, manager_section)
 
-    toml_output.write(tomlkit.dumps(doc, sort_keys=True))
+        if pkg_data:
+            doc += "\n" + tomli_w.dumps({manager.id: pkg_data})
+
+    toml_output.write(doc)
 
     if stats:
         print_stats(installed_data)
@@ -794,19 +828,18 @@ def backup(ctx, toml_output):
 def restore(ctx, toml_files):
     """Read TOML files then install or upgrade each package referenced in
     them.
+
+    Version specified in the TOML file is ignored in the current implementation.
     """
     active_managers = ctx.obj["active_managers"]
 
     for toml_input in toml_files:
 
-        toml_filepath = (
-            toml_input.name
-            if toml_input is __stdin__
-            else Path(toml_input.name).resolve()
-        )
+        is_stdin = isinstance(toml_input, TextIOWrapper)
+        toml_filepath = toml_input.name if is_stdin else Path(toml_input.name).resolve()
         logger.info(f"Load package list from {toml_filepath}")
 
-        doc = tomlkit.parse(toml_input.read())
+        doc = tomli.loads(toml_input.read())
 
         # List unrecognized sections.
         ignored_sections = [f"[{section}]" for section in doc if section not in pool()]
@@ -820,6 +853,6 @@ def restore(ctx, toml_files):
                 logger.warning(f"No [{manager.id}] section found.")
                 continue
             logger.info(f"Restore {manager.id} packages...")
-            logger.warning("Installation of packages not implemented yet.")
-            # for package_id, version in doc[manager.id].items():
-            #    raise NotImplemented
+            for package_id, version in doc[manager.id].items():
+                output = manager.install(package_id)
+                click.echo(output)
