@@ -94,8 +94,6 @@ class MAS(PackageManager):
         output = self.run_cli(self.global_args, "search", query)
 
         if output:
-            regexp = re.compile(r"(\d+) (.*)$")
-
             regexp = re.compile(
                 r"""
                 (?P<package_id>\d+)
@@ -124,6 +122,17 @@ class MAS(PackageManager):
 
         return matches
 
+    def install(self, package_id):
+        """Install one package.
+
+        .. code-block:: shell-session
+
+            ► mas install 945397020
+
+        """
+        super().install(package_id)
+        return self.run_cli(self.global_args, "install", package_id)
+
     @property
     def outdated(self):
         """Fetch outdated packages from ``mas outdated`` output.
