@@ -118,6 +118,17 @@ class Snap(PackageManager):
                 }
         return matches
 
+    def install(self, package_id):
+        """Install one package.
+
+        .. code-block:: shell-session
+
+            ► snap install standard-notes
+
+        """
+        super().install(package_id)
+        return self.run_cli(self.global_args, "install", package_id)
+
     @property
     def outdated(self):
         """Fetch outdated packages from ``snap refresh --list`` output.
