@@ -15,7 +15,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-import logging
 import re
 from pathlib import Path
 
@@ -26,7 +25,7 @@ from boltons.iterutils import flatten
 from boltons.strutils import strip_ansi
 from cli_helpers.tabular_output import TabularOutputFormatter
 
-from .. import __version__, logger
+from .. import __version__, config
 from ..cli import RENDERING_MODES, WINDOWS_MODE_BLACKLIST
 from .conftest import MANAGER_IDS, unless_windows
 
@@ -45,6 +44,24 @@ def test_temporary_fs(runner):
     assert not str(Path(__file__)).startswith(str(Path.cwd()))
 
 
+DUMMY_CONF_FILE = """
+        # Comment
+
+        top_level_param = "to_ignore"
+
+        [mpm]
+        verbosity = "DEBUG"
+        blahblah = 234
+        manager = ["pip", "npm", "gem"]
+
+        [garbage]
+
+        [mpm.search]
+        exact = true
+        dummy_parameter = 3
+        """
+
+
 class TestBaseCLI:
 
     """This collection is testing basic CLI behavior shared by all
@@ -53,19 +70,14 @@ class TestBaseCLI:
     Also regroups tests not involving subcommands.
 
     Also includes a bunch of tests performed once on an arbitrary sub-command,
-    for situation when the tested behavior is shared by all subcommands. In
-    that case we choosed `managers` as it is a safe read-only operation
-    supposed to work on all platforms whatever the environment.
+    for situation when the tested behavior is shared by all subcommands. The
+    arbitrary sub-command is `managers`, as it is a safe read-only operation
+    supposed to work on all platforms, whatever the environment.
     """
 
-    def test_bare_call(self, invoke):
-        result = invoke()
-        assert result.exit_code == 0
-        assert "Usage: " in result.stdout
-        assert not result.stderr
-
-    def test_main_help(self, invoke):
-        result = invoke("--help")
+    @pytest.mark.parametrize("param", [None, "--help", "-h"])
+    def test_main_help(self, invoke, param):
+        result = invoke(param)
         assert result.exit_code == 0
         assert "Usage: " in result.stdout
         assert not result.stderr
@@ -80,7 +92,7 @@ class TestBaseCLI:
         result = invoke("--blah")
         assert result.exit_code == 2
         assert not result.stdout
-        assert "Error: no such option: --blah" in result.stderr
+        assert "Error: No such option: --blah" in result.stderr
 
     def test_unknown_command(self, invoke):
         result = invoke("blah")
@@ -94,6 +106,25 @@ class TestBaseCLI:
         assert not result.stdout
         assert "Error: Missing command." in result.stderr
 
+    @pytest.mark.parametrize(
+        "params", [["--version"], ["blah"], ["--config", "random.toml"]]
+    )
+    def test_help_eagerness(self, invoke, params):
+        # See: https://click.palletsprojects.com/en/8.0.x/advanced/#callback-evaluation-order
+        result = invoke("--help", params)
+        assert result.exit_code == 0
+        assert "Usage: " in result.stdout
+        assert not result.stderr
+
+    @pytest.mark.parametrize(
+        "params", [["--help"], ["blah"], ["--config", "random.toml"]]
+    )
+    def test_version_eagerness(self, invoke, params):
+        result = invoke("--version", params)
+        assert result.exit_code == 0
+        assert __version__ in result.stdout
+        assert not result.stderr
+
     def test_unrecognized_verbosity(self, invoke):
         result = invoke("--verbosity", "random", "managers")
         assert result.exit_code == 2
@@ -104,13 +135,70 @@ class TestBaseCLI:
     def test_verbosity(self, invoke, level):
         result = invoke("--verbosity", level, "managers")
         assert result.exit_code == 0
-        assert logger.level == getattr(logging, level)
-        assert "══════" in result.stdout
+        assert "──────" in result.stdout
         if level == "DEBUG":
             assert "debug: " in result.stderr
         else:
             assert "debug: " not in result.stderr
 
+    def test_unset_conf_no_message(self, invoke):
+        result = invoke("managers")
+        assert result.exit_code == 0
+        assert f"Load configuration at " not in result.stderr
+
+    def test_unset_conf_debug_message(self, invoke):
+        result = invoke("--verbosity", "DEBUG", "managers")
+        assert result.exit_code == 0
+        assert (
+            f"debug: Configuration not found at {config.default_conf_path()}"
+            in result.stderr
+        )
+        assert "debug: Ignore configuration file." in result.stderr
+        assert "debug: Loaded configuration: {}" in result.stderr
+
+    def test_conf_not_exist(self, invoke):
+        conf_path = config.default_conf_path().parent / "dummy.toml"
+        result = invoke("--config", str(conf_path), "managers")
+        assert result.exit_code == 2
+        assert f"critical: Configuration not found at {conf_path}" in result.stderr
+
+    def test_conf_not_file(self, invoke):
+        conf_path = config.default_conf_path().parent
+        result = invoke("--config", str(conf_path), "managers")
+        assert result.exit_code == 2
+        assert f"critical: Configuration {conf_path} is not a file." in result.stderr
+
+    def test_read_specific_conf(self, invoke, create_toml):
+        conf_path = create_toml("configuration.extension", DUMMY_CONF_FILE)
+        result = invoke("--config", str(conf_path), "managers")
+        assert result.exit_code == 0
+        assert f"Load configuration at {conf_path}" in result.stderr
+
+    def test_conf_file_overrides_defaults(self, invoke, create_toml):
+        create_toml(config.default_conf_path(), DUMMY_CONF_FILE)
+        result = invoke("managers")
+        assert result.exit_code == 0
+        assert " │ pip │ " in result.stdout
+        assert " │ npm │ " in result.stdout
+        assert " │ gem │ " in result.stdout
+        assert "brew" not in result.stdout
+        assert "cask" not in result.stdout
+        assert "debug: " in result.stderr
+
+    def test_conf_file_cli_override(self, invoke, create_toml):
+        create_toml(config.default_conf_path(), DUMMY_CONF_FILE)
+        result = invoke("--verbosity", "CRITICAL", "managers")
+        assert result.exit_code == 0
+        assert " │ pip │ " in result.stdout
+        assert " │ npm │ " in result.stdout
+        assert " │ gem │ " in result.stdout
+        assert "brew" not in result.stdout
+        assert "cask" not in result.stdout
+        assert "error: " not in result.stderr
+        assert "warning: " not in result.stderr
+        assert "info: " not in result.stderr
+        assert "debug: " not in result.stderr
+
     @unless_windows
     @pytest.mark.parametrize("mode", WINDOWS_MODE_BLACKLIST)
     def test_check_failing_unicode_rendering(self, mode):
@@ -198,6 +286,13 @@ class CLISubCommandTests:
                 f"Restore {mid} packages..." in result.stderr,
                 # Warning message for restore command.
                 f"warning: No [{mid}] section found." in result.stderr,
+                # Install message.
+                bool(
+                    re.search(
+                        fr"Install \S+ package from {mid}...",
+                        result.stderr,
+                    )
+                ),
             ]
 
             if True in signals:
@@ -279,13 +374,14 @@ class CLITableTests:
     A table output is also allowed to be rendered as JSON.
     """
 
-    # List of all supported rendering modes IDs, and their expected output.
+    # List of all supported rendering modes IDs, their expected output and the other
+    # mode they are allowed to conflict with.
     expected_renderings = {
         "ascii": ("---+---", None),
         "csv": (",", None),
         "csv-tab": ("\t", None),
         "double": ("═══╬═══", None),
-        "fancy_grid": ("═══╪═══", None),
+        "fancy_grid": ("═══╪═══", "psql_unicode"),
         "github": ("---|---", None),
         "grid": ("===+===", "ascii"),
         "html": ("<table>", None),
@@ -294,11 +390,13 @@ class CLITableTests:
         "latex": ("\\hline", None),
         "latex_booktabs": ("\\toprule", None),
         "mediawiki": ('{| class="wikitable" ', "jira"),
+        "minimal": ("  ", None),
         "moinmoin": (" ''' || ''' ", "jira"),
         "orgtbl": ("---+---", None),
         "pipe": ("---|:---", None),
         "plain": ("  ", None),
         "psql": ("---+---", None),
+        "psql_unicode": ("───┼───", None),
         "rst": ("===  ===", None),
         "simple": ("---  ---", None),
         "textile": (" |_. ", None),
@@ -312,11 +410,11 @@ class CLITableTests:
         assert RENDERING_MODES == set(self.expected_renderings.keys())
 
     def test_default_table_rendering(self, invoke, subcmd):
-        """Check default rendering is fancy_grid."""
+        """Check default rendering is psql_unicode."""
         result = invoke(subcmd)
         assert result.exit_code == 0
 
-        expected = self.expected_renderings["fancy_grid"][0]
+        expected = self.expected_renderings["psql_unicode"][0]
 
         # If no package found, check that no table gets rendered. Else, check
         # the selected mode is indeed rendered in <stdout>, so the CLI result
